Fit a model that contains both a trait-matching and a centrality term based on Rohr et al. (2016)
FitBothMandC(list, N_runs = 10, maxit = 10000,
method = "Nelder-Mead", ExtraSettings = NULL)Network List
Number of different start points for k2 and lambda to try. The best (maximum likelihood) half will be used to construct the probability matrix
Default = 10'000
Passed to optim, default = 'Nelder-Mead'
Other control settings to pass to optim()
Network list with added 'B_par',the best fitting parameters, 'M_ProbsMatrix', the probability matrix
Rohr, R.P., Naisbit, R.E., Mazza, C. & Bersier, L.-F. (2016). Matching-centrality decomposition and the forecasting of new links in networks. Proc. R. Soc. B Biol. Sci., 283, 20152702