Fit SBM Model
FitSBM(list, n_SBM = 10, G = NULL)Network List
Number of SBM models to fit. Default is 10. The top half (rounding up) are retained and averaged to produce a probability matrix.
The number of groups to divide the top layer and the focal layer into.
Network list with 'SBM_ProbsMat', a matrix of probabilities assigned to each possible interaction, 'SBM1', the best model fit derived from Optimise_SBM(), and 'SBM_G', the number of fitted groups.